^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Changelog for package diagnostic_msgs
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

4.2.4 (2024-05-21)
------------------

4.2.3 (2023-01-09)
------------------

4.2.2 (2022-05-19)
------------------

4.2.1 (2022-03-31)
------------------

4.2.0 (2022-03-30)
------------------

4.1.1 (2022-03-26)
------------------

4.1.0 (2022-03-01)
------------------
* Interface packages should fully <depend> on the interface packages that they depend on (`#173 <https://github.com/ros2/common_interfaces/issues/173>`_)
* Contributors: Grey

4.0.0 (2021-12-14)
------------------
* Update maintainers to Geoffrey Biggs and Tully Foote (`#163 <https://github.com/ros2/common_interfaces/issues/163>`_)
* Contributors: Audrow Nash

3.0.0 (2021-08-24)
------------------

2.3.0 (2021-08-11)
------------------

2.2.3 (2021-04-27)
------------------

2.2.2 (2021-04-06)
------------------
* Change index.ros.org -> docs.ros.org. (`#149 <https://github.com/ros2/common_interfaces/issues/149>`_)
* updating quality declaration links (re: `ros2/docs.ros2.org#52 <https://github.com/ros2/docs.ros2.org/issues/52>`_) (`#145 <https://github.com/ros2/common_interfaces/issues/145>`_)
* Contributors: Chris Lalancette, shonigmann

2.2.1 (2021-01-25)
------------------

2.2.0 (2020-12-10)
------------------
* Update QDs to QL 1 (`#135 <https://github.com/ros2/common_interfaces/issues/135>`_)
* Update package maintainers. (`#132 <https://github.com/ros2/common_interfaces/issues/132>`_)
* Updated Quality Level to 2 (`#131 <https://github.com/ros2/common_interfaces/issues/131>`_)
* Contributors: Alejandro Hernández Cordero, Michel Hidalgo, Stephen Brawner

2.1.0 (2020-07-21)
------------------

2.0.2 (2020-07-21)
------------------
* Update Quality levels to level 3 (`#124 <https://github.com/ros2/common_interfaces/issues/124>`_)
* Add Security Vulnerability Policy pointing to REP-2006. (`#120 <https://github.com/ros2/common_interfaces/issues/120>`_)
* Contributors: Chris Lalancette, brawner

2.0.1 (2020-05-26)
------------------
* QD Update Version Stability to stable version (`#121 <https://github.com/ros2/common_interfaces/issues/121>`_)
* Contributors: Alejandro Hernández Cordero

1.0.0 (2020-05-20)
------------------
* Add current-level quality declarations (`#109 <https://github.com/ros2/common_interfaces/issues/109>`_)
* Contributors: brawner
